@@ -63,6 +63,9 @@ class Remote(AppiumWebDriver):
         job_name: str = None,
         disable_reports: bool = False,
         report_type: ReportType = ReportType.CLOUD_AND_LOCAL,
+        agent_url: str = None,
+        report_name: str = None,
+        report_path: str = None,
     ):
         if Remote.__instance is not None:
             raise SdkException("A driver session already exists")
@@ -87,11 +90,12 @@ class Remote(AppiumWebDriver):
                 # Can update job name at runtime if not specified.
                 os.environ[EnvironmentVariable.TP_UPDATE_JOB_NAME.value] = "True"
 
-        report_settings = ReportSettings(self._project_name, self._job_name, report_type)
+        report_settings = ReportSettings(self._project_name, self._job_name, report_type, report_name, report_path)
 
         self._agent_client: AgentClient = AgentClient(
             token=self._token,
             capabilities=self._desired_capabilities,
+            agent_url=agent_url,
             report_settings=report_settings,
         )
         self._agent_session: AgentSession = self._agent_client.agent_session
@@ -108,6 +112,8 @@ class Remote(AppiumWebDriver):
             remote_server_addr=self._agent_session.remote_address,
         )
 
+        self.command_executor.disable_reports = disable_reports
+
         # this ensures that mobile-specific commands are also available for our command executor
         self._addCommands()
 
